@@ -17,19 +17,26 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: popup-blocker.c,v 1.1 2003/12/28 01:23:57 uid68685 Exp $
+ *  $Id: popup-blocker.c,v 1.1 2004/01/02 07:12:02 chpe Exp $
  */
 
 #include "ephy-popup-blocker-extension.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
+#include <glib/gi18n-lib.h>
 
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
 	LOG ("Registering EphyPopupBlockerExtension")
 
+#ifdef ENABLE_NLS
+	/* Initialise the i18n stuff */
+	bindtextdomain (GETTEXT_PACKAGE, EPHY_EXTENSIONS_LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif /* ENABLE_NLS */
+
 	return ephy_popup_blocker_extension_register_type (module);
 }
 
